fix_format

Change-Id: I34e265de434263a11654e5deba044c3f21e86578


[ROCm/clr commit: 1fe6890ba3]
此提交包含在:
Sandeep Kumar
2016-11-15 12:41:05 +05:30
提交者 Maneesh Gupta
父節點 b13556367d
當前提交 b8eda419a8
共有 2 個檔案被更改,包括 41 行新增42 行删除
+6 -6
查看文件
@@ -108,7 +108,7 @@ void disablePeer2Peer(int currentGpu, int peerGpu)
HIPCHECK(hipSetDevice(currentGpu));
hipDeviceCanAccessPeer(&canAccessPeer, currentGpu, peerGpu);
if(canAccessPeer==1){
HIPCHECK(hipDeviceDisablePeerAccess(peerGpu));
}
@@ -155,7 +155,7 @@ __global__ void matrixTranspose_dynamic_shared(hipLaunchParm lp,
int main(){
checkPeer2PeerSupport();
int gpuCount;
int currentGpu, peerGpu;
@@ -191,10 +191,10 @@ int main(){
0, 0,
gpuTransposeMatrix[0], data[0], width);
HIPCHECK(hipSetDevice(peerGpu));
TransposeMatrix[1] = (float*)malloc(NUM * sizeof(float));
hipMalloc((void**)&gpuTransposeMatrix[1], NUM * sizeof(float));
hipMalloc((void**)&data[1], NUM * sizeof(float));
HIPCHECK(hipSetDevice(peerGpu));
TransposeMatrix[1] = (float*)malloc(NUM * sizeof(float));
hipMalloc((void**)&gpuTransposeMatrix[1], NUM * sizeof(float));
hipMalloc((void**)&data[1], NUM * sizeof(float));
hipMemcpy(data[1], gpuTransposeMatrix[0], NUM * sizeof(float), hipMemcpyDeviceToDevice);
hipLaunchKernel(matrixTranspose_dynamic_shared,